@@ -33,7 +33,7 @@ define('GOLLEM_SORT_DESCEND', 1);
 /**
  * Gollem Base Class.
  *
- * $Horde: gollem/lib/Gollem.php,v 1.172.2.18 2006/02/22 06:48:38 slusarz Exp $
+ * $Horde: gollem/lib/Gollem.php,v 1.172.2.20 2006/05/19 17:14:06 slusarz Exp $
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -48,13 +48,13 @@ class Gollem {
      * Check Gollem authentication and change to the currently active
      * directory. Redirects to login page on authentication/session failure.
      *
+     * @param string $mode       The authentication mode we are using.
      * @param boolean $redirect  Redirect to the logout page if authentication
      *                           is unsuccessful?
-     * @param string $mode       The authentication mode we are using.
      *
      * @return boolean  True on success, false on failure.
      */
-    function checkAuthentication($redirect = true, $mode = null)
+    function checkAuthentication($mode = null, $redirect = true)
     {
         $auth_gollem = &Auth::singleton(array('gollem', 'gollem'));
         $reason = $auth_gollem->authenticate();
@@ -779,16 +779,18 @@ class Gollem {
         }
 
         if (!empty($_SESSION['gollem'])) {
+            $backend_key = $_SESSION['gollem']['backend_key'];
             if (Auth::isAdmin()) {
-                $menu->add(Util::addParameter(Horde::applicationUrl('permissions.php'), 'backend', $_SESSION['gollem']['backend_key']), _("Permissions"), 'administration.png', $GLOBALS['registry']->getImageDir('horde'));
+                $menu->add(Util::addParameter(Horde::applicationUrl('permissions.php'), 'backend', $backend_key), _("Permissions"), 'administration.png', $GLOBALS['registry']->getImageDir('horde'));
             }
 
-            if ($_SESSION['gollem']['hasquota']) {
+            if ($_SESSION['gollem']['hasquota'] &&
+                ($_SESSION['gollem']['backends'][$backend_key]['quota_val'] != -1)) {
                 if ($GLOBALS['browser']->hasFeature('javascript')) {
                     Horde::addScriptFile('open_quota_win.js', 'gollem');
-                    $quota_url = 'javascript:open_quota_win(\'' . addslashes('backend=' . $_SESSION['gollem']['backend_key']) . '\');';
+                    $quota_url = 'javascript:open_quota_win(\'' . addslashes('backend=' . $backend_key) . '\');';
                 } else {
-                    $quota_url = Util::addParameter(Horde::applicationUrl('quota.php'), 'backend', $_SESSION['gollem']['backend_key']);
+                    $quota_url = Util::addParameter(Horde::applicationUrl('quota.php'), 'backend', $backend_key);
                 }
                 $menu->add($quota_url, _("Check Quota"), 'info_icon.png', $GLOBALS['registry']->getImageDir('horde'));
             }
@@ -953,7 +955,7 @@ class Gollem {
         if (!isset($be_config['quota_val'])) {
             /* Only set quota information when we are finished with session
              * initialization (a VFS object is created in
-             * MIMP_Session::createSession before all session variables -
+             * Gollem_Session::createSession before all session variables -
              * e.g. 'hasquota' - are set.) */
             $sess_setup = isset($_SESSION['gollem']['hasquota']);
             if ($sess_setup) {
