@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: gollem/manager.php,v 1.146.2.16 2006/03/14 07:18:43 slusarz Exp $
+ * $Horde: gollem/manager.php,v 1.146.2.19 2007/01/02 13:54:52 jan Exp $
  *
- * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2006 Max Kalika <max@horde.org>
+ * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Max Kalika <max@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did notcan receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -254,10 +254,14 @@ foreach (array('owner', 'group', 'all') as $val) {
     }
 }
 
+$all_columns = array('type', 'name', 'edit', 'download', 'modified', 'size', 'permission', 'owner', 'group');
+foreach ($all_columns as $column) {
+    $template->set('columns_' . $column, in_array($column, $columns), true);
+}
+
 $template->set('save', _("Save"));
 $template->set('cancel', _("Cancel"));
 $template->set('ok', _("OK"));
-
 $template->set('action', $manager_url);
 $template->set('forminput', Util::formInput());
 $template->set('dir', $currdir);
@@ -278,7 +282,7 @@ if ($edit_permissions) {
     $template->set('perms_edit', true, true);
     $template->set('upload_file', _("Upload File(s)"));
     $template->set('upload_help', Help::link('gollem', 'file-upload'));
-    $template->set('perms_chmod', in_array('permissions', $columns), true);
+    $template->set('perms_chmod', in_array('permission', $columns), true);
 } else {
     $template->set('perms_edit', false, true);
     $template->set('perms_chmod', false, true);
@@ -296,12 +300,6 @@ if (count($list)) {
     $template->set('list_count', false, true);
 }
 
-/* Set up column listing for cloop. */
-$columns_cloop = array();
-foreach ($columns as $val) {
-    $columns_cloop[] = array('case' => $val);
-}
-
 $icon_cache = array();
 
 if (is_array($list) &&
@@ -490,7 +488,6 @@ if (is_array($list) &&
     /* Set up the template tags. */
     $template->set('headers', $headers, true);
     $template->set('entry', $entry, true);
-    $template->setCloop('columns', $columns_cloop, $columns);
     $template->set('size_caption', $size_caption);
     $template->set('checkall', Horde::getAccessKeyAndTitle(_("Check _All/None")));
 
