@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: gollem/view.php,v 1.51.2.1 2006/01/01 21:28:47 jan Exp $
+ * $Horde: gollem/view.php,v 1.51.2.3 2007/01/02 13:54:52 jan Exp $
  *
- * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2006 Max Kalika <max@horde.org>
+ * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Max Kalika <max@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -36,7 +36,7 @@ if (is_a($data, 'PEAR_Error')) {
 /* Run through action handlers. */
 switch ($actionID) {
 case 'download_file':
-    $browser->downloadHeaders($filename);
+    $browser->downloadHeaders($filename, null, false, strlen($data));
     echo $data;
     break;
 
